# DeepTile
Large image tiling and stitching library for scaling Python functions to arbitrary input image sizes.

## General
DeepTile provides a standardized workflow for splitting large images into tiles of a specified size, processing tiles using regular Python functions, and stitching the processed tiles. DeepTile supports batch processing specifically designed for deep learning algorithms, featuring automatic padding and mini-batch generation.

## Installation

Install DeepTile from [PyPI](https://pypi.org/project/deeptile/).

```
pip install deeptile
```

## Usage

See [notebooks](notebooks) for examples of DeepTile usage for both TIFF and ND2 files.
